==> downloads.html?file=gigkalender_v1.2.61_059.zip: gigkalender/submenues/admin.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
echo '<ul id="Submenue">
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=setup"';
    if ($Inhalt=="setup"
        OR $Inhalt=="updateSetup"
        OR $Inhalt=="editAttributes")
    {echo ' class="selected"';} echo '>
      <img src="images/setup.gif" alt="'.$L_Button12.'" />
        '.$L_Button12.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=showUsers"';
    if ($Inhalt=="showUsers"
        OR $Inhalt=="addUser"
        OR $Inhalt=="delUser")
    {echo ' class="selected"';} echo '>
      <img src="images/users.gif" alt="'.$L_Button10.'" />
        '.$L_Button10.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=frontend"';
    if ($Inhalt=="frontend")
    {echo ' class="selected"';} echo '>
      <img src="images/frontend.gif" alt="'.$L_Button25.'" />
        '.$L_Button25.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=export"';
    if ($Inhalt=="export")
    {echo ' class="selected"';} echo '>
      <img src="images/export.gif" alt="'.$L_Button13.'" />
        '.$L_Button13.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=import"';
    if ($Inhalt=="import")
    {echo ' class="selected"';} echo '>
      <img src="images/export.gif" alt="'.$L_Button31.'" />
        '.$L_Button31.'
    </a>
  </li>';
  echo '</ul>';
?>

==> downloads.html?file=gigkalender_v1.2.66_014.zip: gigkalender/submenues/admin.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
echo '<ul id="Submenue">
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=setup"';
    if ($Inhalt=="setup"
        OR $Inhalt=="updateSetup"
        OR $Inhalt=="editAttributes")
    {echo ' class="selected"';} echo '>
      <img src="images/setup.gif" alt="'.$L_Button12.'" />
        '.$L_Button12.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=tools"';
    if ($Inhalt=="tools")
    {echo ' class="selected"';} echo '>
      <img src="images/tools.gif" alt="'.$L_Button47.'" />
        '.$L_Button47.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=showUsers"';
    if ($Inhalt=="showUsers"
        OR $Inhalt=="addUser"
        OR $Inhalt=="delUser")
    {echo ' class="selected"';} echo '>
      <img src="images/users.gif" alt="'.$L_Button10.'" />
        '.$L_Button10.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=frontend"';
    if ($Inhalt=="frontend")
    {echo ' class="selected"';} echo '>
      <img src="images/frontend.gif" alt="'.$L_Button25.'" />
        '.$L_Button25.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=export"';
    if ($Inhalt=="export")
    {echo ' class="selected"';} echo '>
      <img src="images/export.gif" alt="'.$L_Button13.'" />
        '.$L_Button13.'
    </a>
  </li>
  <li>
    <a href="index.php?submenue=admin&amp;inhalt=import"';
    if ($Inhalt=="import")
    {echo ' class="selected"';} echo '>
      <img src="images/export.gif" alt="'.$L_Button31.'" />
        '.$L_Button31.'
    </a>
  </li>';
  echo '</ul>';
?>
